@@ -38,7 +38,8 @@ typedef enum
 	ANJUTA_PROPERTY_OBJECT_TYPE_TEXT,
 	ANJUTA_PROPERTY_OBJECT_TYPE_COLOR,
 	ANJUTA_PROPERTY_OBJECT_TYPE_FONT,
-	ANJUTA_PROPERTY_OBJECT_TYPE_FILE
+	ANJUTA_PROPERTY_OBJECT_TYPE_FILE,
+	ANJUTA_PROPERTY_OBJECT_TYPE_FOLDER
 } AnjutaPropertyObjectType;
 
 typedef enum
