@@ -596,8 +596,8 @@ anjuta_util_get_real_path (const gchar *path)
 {
 	if (path != NULL)
 	{
-#ifdef PATH_MAX
 		gchar *result;
+#ifdef PATH_MAX
 		gchar buf[PATH_MAX+1];
 
 		result = realpath (path, buf);
@@ -607,9 +607,16 @@ anjuta_util_get_real_path (const gchar *path)
 			return g_strdup (buf);
 		}
 #else
-		/* strictly, the string returned from this should be cleaned with
+		char *buf;
+		/* the string returned by realpath should be cleaned with
 		   free(), not g_free() */
-		return (realpath (path, NULL));
+		buf = realpath (path, NULL);
+		if (buf != NULL)
+		{
+			result = g_strdup (buf);
+			free (buf);
+			return result;
+		}
 #endif
 	}
 	return NULL;
@@ -786,7 +793,7 @@ anjuta_util_execute_shell (const gchar *dir, const gchar *command)
 		_exit(1);
 	}
 	if (pid < 0)
-		g_warning (_("Cannot execute command %s (using shell %s)\n"), command, shell);
+		g_warning (_("Cannot execute command: %s (using shell %s)\n"), command, shell);
 	g_free (shell);
 	// Anjuta will take care of child exit automatically.
 	return pid;
@@ -848,7 +855,7 @@ anjuta_util_parse_args_from_string (const gchar* string)
 		} else if (*s == '\\') {
 			/* Current char is an escape */
 			escaped = TRUE;
-		} else if (*s == quote) {
+		} else if (is_quote && *s == quote) {
 			/* Current char ends a quotation */
 			is_quote = FALSE;
 			if (!isspace(*(s+1)) && (*(s+1) != '\0')) {
@@ -991,7 +998,7 @@ anjuta_util_get_uri_mime_type (const gchar *uri)
 	 */
 	if (!path)
 	{
-		mime_type = gnome_vfs_get_mime_type (uri);
+		mime_type = gnome_vfs_get_slow_mime_type (uri);
 	}
 	else if (anjuta_util_path_has_extension (path, "anjuta"))
 	{
@@ -1011,7 +1018,7 @@ anjuta_util_get_uri_mime_type (const gchar *uri)
 	}
 	else
 	{
-		mime_type = gnome_vfs_get_mime_type (uri);
+		mime_type = gnome_vfs_get_slow_mime_type (uri);
 	}
 	
 	if (vfs_uri)
