@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifndef _ANJUTA_UTILS_H_
 #define _ANJUTA_UTILS_H_
@@ -26,8 +26,6 @@
 
 #include <libanjuta/anjuta-preferences.h>
 
-#include "config.h"
-
 G_BEGIN_DECLS
 
 gboolean anjuta_util_copy_file (gchar * src, gchar * dest, gboolean show_error);
@@ -110,14 +108,10 @@ pid_t anjuta_util_execute_shell (const gchar *dir, const gchar *command);
 gchar* anjuta_util_escape_quotes(const gchar* str);
 
 gboolean anjuta_util_path_has_extension (const gchar *path, const gchar *ext);
+gchar* anjuta_util_get_real_path (const gchar *path);
 
 gchar* anjuta_util_get_uri_mime_type (const gchar *uri);
 
-#ifndef HAVE_LIBUTIL
-#include <grp.h>
-int forkpty(int *amaster, char *name, struct termios *termp, struct winsize *winp);
-#endif /* HAVE_LIBUTIL */
-
 /* Temporarily copied here */
 
 #define ANJUTA_TYPE_BEGIN(class_name, prefix, parent_type) \
