@@ -21,7 +21,6 @@
 #define LIBANJUTA_H
 
 /* FIXME: Update required */
-#include <libanjuta/anjuta-children.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-encodings.h>
 #include <libanjuta/anjuta-enum-types.h>
@@ -43,5 +42,8 @@
 #include <libanjuta/anjuta-ui.h>
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
+#include <libanjuta/anjuta-vcs-status-tree-view.h>
+#include <libanjuta/anjuta-command.h>
+#include <libanjuta/anjuta-async-command.h>
 
 #endif
