@@ -252,7 +252,7 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 				error_condition = TRUE;
 				target = NULL;
 				anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell),
-										  _("No file or Project opened."));
+										  _("No file or project currently opened."));
 			}
 			else
 			{
@@ -393,6 +393,35 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 										   IAnjutaTerminal, NULL);
 		if (term)
 		{
+			
+
+			if (plugin->commands[IANJUTA_BUILDABLE_COMMAND_EXECUTE])
+			{
+				gchar *oldcmd = cmd;
+
+				cmd = g_strdup_printf (plugin->commands[IANJUTA_BUILDABLE_COMMAND_EXECUTE],
+					oldcmd);
+
+				g_free (oldcmd);
+			} else {
+				gchar* launcher_path = g_find_program_in_path("anjuta_launcher");
+
+				if (launcher_path != NULL)
+				{
+					gchar* oldcmd = cmd;
+				
+					cmd = g_strconcat ("anjuta_launcher ", oldcmd, NULL);
+
+					g_free (oldcmd);
+					g_free (launcher_path);
+				}
+				else
+				{
+					DEBUG_PRINT("Missing anjuta_launcher");
+				}
+				
+			}
+
 			ianjuta_terminal_execute_command (term, dir, cmd, NULL);
 		}
 		else
