@@ -158,7 +158,7 @@ dma_debugger_queue_clear (DmaDebuggerQueue *self)
 }
 		
 static void
-dma_queue_emit_debugger_state (DmaDebuggerQueue *self, IAnjutaDebuggerState state, GError* err)
+dma_queue_emit_debugger_state_change (DmaDebuggerQueue *self, IAnjutaDebuggerState state, GError* err)
 {
 	enum
 	{
@@ -172,102 +172,56 @@ dma_queue_emit_debugger_state (DmaDebuggerQueue *self, IAnjutaDebuggerState stat
 		PROGRAM_RUNNING_SIGNAL,
 		PROGRAM_STOPPED_SIGNAL
 	} signal = NO_SIGNAL;
-	gboolean emit_program_started = FALSE;
 	
-	DEBUG_PRINT("update debugger state new %d old %d", state, self->debugger_state);
+	DEBUG_PRINT("change debugger state new %d old %d", state, self->debugger_state);
 
-	/* Add missing state if useful */
 	switch (state)
 	{
+	case IANJUTA_DEBUGGER_BUSY:
+		/* Debugger is busy, nothing to do */
+		g_return_if_reached();
+		return;
 	case IANJUTA_DEBUGGER_STOPPED:
-		if ((self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_RUNNING) ||
-			(self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_STOPPED))
-		{
-			dma_queue_emit_debugger_state (self, IANJUTA_DEBUGGER_PROGRAM_LOADED, NULL);
-		}
-		else if	(self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_LOADED)
-		{
-			dma_queue_emit_debugger_state (self, IANJUTA_DEBUGGER_STARTED, NULL);
-		}
+		self->stop_on_sharedlib = FALSE;
+		signal = DEBUGGER_STOPPED_SIGNAL;
+		self->debugger_state = state;
 		break;
 	case IANJUTA_DEBUGGER_STARTED:
-		if ((self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_RUNNING) ||
-			(self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_STOPPED))
-		{
-			dma_queue_emit_debugger_state (self, IANJUTA_DEBUGGER_PROGRAM_LOADED, NULL);
-		}
+		self->stop_on_sharedlib = FALSE;
+		signal = self->debugger_state < IANJUTA_DEBUGGER_STARTED ? DEBUGGER_STARTED_SIGNAL : PROGRAM_UNLOADED_SIGNAL;			
+		self->debugger_state = state;
 		break;
 	case IANJUTA_DEBUGGER_PROGRAM_LOADED:
-		if (self->debugger_state == IANJUTA_DEBUGGER_STOPPED)
-		{
-			dma_queue_emit_debugger_state (self, IANJUTA_DEBUGGER_STARTED, NULL);
-		}
+		self->stop_on_sharedlib = FALSE;
+		signal = self->debugger_state < IANJUTA_DEBUGGER_PROGRAM_LOADED ? PROGRAM_LOADED_SIGNAL : PROGRAM_EXITED_SIGNAL;			
+		self->debugger_state = state;
 		break;
 	case IANJUTA_DEBUGGER_PROGRAM_STOPPED:
-		if (self->debugger_state == IANJUTA_DEBUGGER_STOPPED)
+		if (self->debugger_state < IANJUTA_DEBUGGER_PROGRAM_STOPPED)
 		{
-			dma_queue_emit_debugger_state (self, IANJUTA_DEBUGGER_STARTED, NULL);
+			signal = PROGRAM_STARTED_SIGNAL;
+			/* Emit a debugger stopped after program started */
+			self->debugger_state = IANJUTA_DEBUGGER_PROGRAM_RUNNING;
+			break;
 		}
-		else if (self->debugger_state == IANJUTA_DEBUGGER_STARTED)
+		if (!self->stop_on_sharedlib)
 		{
-			dma_queue_emit_debugger_state (self, IANJUTA_DEBUGGER_PROGRAM_LOADED, NULL);
+			signal = PROGRAM_STOPPED_SIGNAL;			
 		}
+		self->debugger_state = state;
 		break;
 	case IANJUTA_DEBUGGER_PROGRAM_RUNNING:
-		if (self->debugger_state == IANJUTA_DEBUGGER_STOPPED)
+		self->stop_on_sharedlib = FALSE;
+		if (self->debugger_state < IANJUTA_DEBUGGER_PROGRAM_STOPPED)
 		{
-			dma_queue_emit_debugger_state (self, IANJUTA_DEBUGGER_STARTED, NULL);
-		}
-		else if (self->debugger_state == IANJUTA_DEBUGGER_STARTED)
-		{
-			dma_queue_emit_debugger_state (self, IANJUTA_DEBUGGER_PROGRAM_LOADED, NULL);
+			signal = PROGRAM_STARTED_SIGNAL;
+			/* Emit a debugger stopped after program started */
+			self->debugger_state = IANJUTA_DEBUGGER_PROGRAM_STOPPED;
+			break;
 		}
+		signal = PROGRAM_RUNNING_SIGNAL;
+		self->debugger_state = state;
 		break;
-	case IANJUTA_DEBUGGER_BUSY:
-		break;
-	}	
-
-	if (self->debugger_state != state)
-	{
-		switch (state)
-		{
-		case IANJUTA_DEBUGGER_BUSY:
-			/* Debugger is busy, nothing to do */
-			return;
-		case IANJUTA_DEBUGGER_STOPPED:
-			self->stop_on_sharedlib = FALSE;
-			signal = DEBUGGER_STOPPED_SIGNAL;
-			self->debugger_state = state;
-			break;
-		case IANJUTA_DEBUGGER_STARTED:
-			self->stop_on_sharedlib = FALSE;
-			signal = self->debugger_state < IANJUTA_DEBUGGER_STARTED ? DEBUGGER_STARTED_SIGNAL : PROGRAM_UNLOADED_SIGNAL;			
-			self->debugger_state = state;
-			break;
-		case IANJUTA_DEBUGGER_PROGRAM_LOADED:
-			self->stop_on_sharedlib = FALSE;
-			signal = self->debugger_state < IANJUTA_DEBUGGER_PROGRAM_LOADED ? PROGRAM_LOADED_SIGNAL : PROGRAM_EXITED_SIGNAL;			
-			self->debugger_state = state;
-			break;
-		case IANJUTA_DEBUGGER_PROGRAM_STOPPED:
-			if (!self->stop_on_sharedlib)
-			{
-				emit_program_started = self->debugger_state < IANJUTA_DEBUGGER_PROGRAM_STOPPED;
-				signal = PROGRAM_STOPPED_SIGNAL;			
-			}
-			else if (self->debugger_state < IANJUTA_DEBUGGER_PROGRAM_STOPPED)
-			{
-				signal = PROGRAM_STARTED_SIGNAL;
-			}
-			self->debugger_state = state;
-			break;
-		case IANJUTA_DEBUGGER_PROGRAM_RUNNING:
-			emit_program_started = self->debugger_state < IANJUTA_DEBUGGER_PROGRAM_STOPPED;
-			self->stop_on_sharedlib = FALSE;
-			signal = PROGRAM_RUNNING_SIGNAL;			
-			self->debugger_state = state;
-			break;
-		}
 	}
 
 	self->prepend_command++;
@@ -302,21 +256,10 @@ dma_queue_emit_debugger_state (DmaDebuggerQueue *self, IAnjutaDebuggerState stat
 		g_signal_emit_by_name (self->plugin, "program-exited");
 		break;
 	case PROGRAM_STOPPED_SIGNAL:
-		DEBUG_PRINT("** emit program-exited **");
-		if (emit_program_started)
-		{	
-			DEBUG_PRINT("** emit program-started **");
-			g_signal_emit_by_name (self->plugin, "program-started");
-		}
 		DEBUG_PRINT("** emit program-stopped **");
 		g_signal_emit_by_name (self->plugin, "program-stopped");
 		break;
 	case PROGRAM_RUNNING_SIGNAL:
-		if (emit_program_started)
-		{	
-			DEBUG_PRINT("** emit program-started **");
-			g_signal_emit_by_name (self->plugin, "program-started");
-		}
 		DEBUG_PRINT("** emit program-running **");
 		g_signal_emit_by_name (self->plugin, "program-running");
 		break;
@@ -324,6 +267,69 @@ dma_queue_emit_debugger_state (DmaDebuggerQueue *self, IAnjutaDebuggerState stat
 	self->prepend_command--;
 }
 
+static void
+dma_queue_emit_debugger_state (DmaDebuggerQueue *self, IAnjutaDebuggerState state, GError* err)
+{
+	DEBUG_PRINT("update debugger state new %d old %d", state, self->debugger_state);
+
+	/* Add missing states if useful */
+	for(;self->debugger_state != state;)
+	{
+		IAnjutaDebuggerState next_state = state;
+		
+		switch (state)
+		{
+		case IANJUTA_DEBUGGER_STOPPED:
+			if ((self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_RUNNING) ||
+				(self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_STOPPED))
+			{
+				next_state = IANJUTA_DEBUGGER_PROGRAM_LOADED;
+			}
+			else if	(self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_LOADED)
+			{
+				next_state = IANJUTA_DEBUGGER_STARTED;
+			}
+			break;
+		case IANJUTA_DEBUGGER_STARTED:
+			if ((self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_RUNNING) ||
+				(self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_STOPPED))
+			{
+				next_state = IANJUTA_DEBUGGER_PROGRAM_LOADED;
+			}
+			break;
+		case IANJUTA_DEBUGGER_PROGRAM_LOADED:
+			if (self->debugger_state == IANJUTA_DEBUGGER_STOPPED)
+			{
+				next_state = IANJUTA_DEBUGGER_STARTED;
+			}
+			break;
+		case IANJUTA_DEBUGGER_PROGRAM_STOPPED:
+			if (self->debugger_state == IANJUTA_DEBUGGER_STOPPED)
+			{
+				next_state = IANJUTA_DEBUGGER_STARTED;
+			}
+			else if (self->debugger_state == IANJUTA_DEBUGGER_STARTED)
+			{
+				next_state = IANJUTA_DEBUGGER_PROGRAM_LOADED;
+			}
+			break;
+		case IANJUTA_DEBUGGER_PROGRAM_RUNNING:
+			if (self->debugger_state == IANJUTA_DEBUGGER_STOPPED)
+			{
+				next_state = IANJUTA_DEBUGGER_STARTED;
+			}
+			else if (self->debugger_state == IANJUTA_DEBUGGER_STARTED)
+			{
+				next_state = IANJUTA_DEBUGGER_PROGRAM_LOADED;
+			}
+			break;
+		case IANJUTA_DEBUGGER_BUSY:
+			return;
+		}
+		dma_queue_emit_debugger_state_change (self, next_state, NULL);
+	}
+}
+
 static void
 dma_queue_emit_debugger_ready (DmaDebuggerQueue *self)
 {
@@ -464,9 +470,9 @@ dma_queue_check_state (DmaDebuggerQueue *self, DmaQueueCommand* cmd)
 	{
 		IAnjutaDebuggerState state;
 		
-		if (self->prepend_command)
+		if (self->prepend_command || dma_command_has_flag (cmd, HIGH_PRIORITY))
 		{
-			/* Prepend command use debugger state or current command state */
+			/* Prepend command and high priority command use debugger state or current command state */
 			if (self->last != NULL)
 			{
 				state = dma_command_is_going_to_state (self->last);
@@ -536,7 +542,7 @@ dma_debugger_activate_plugin (DmaDebuggerQueue* self, const gchar *mime_type)
 	{
 		/* No plugin found */
 		anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (self->plugin)->shell),
-				_("Unable to find one debugger plugin acception %s mime type"), mime_type);
+				_("Unable to find one debugger plugin supporting a target with %s mime type"), mime_type);
 			
 		return FALSE;
 	}
@@ -702,8 +708,11 @@ dma_debugger_queue_command_callback (const gpointer data, gpointer user_data, GE
 	g_return_if_fail (self->last != NULL);
 	
 	self->prepend_command++;
-	dma_command_callback (self->last, data, err);
-	self->prepend_command--;	
+	if (self->queue_state != IANJUTA_DEBUGGER_STOPPED)
+	{
+		dma_command_callback (self->last, data, err);
+	}
+	self->prepend_command--;
 }
 
 gboolean
@@ -730,9 +739,29 @@ dma_debugger_queue_append (DmaDebuggerQueue *self, DmaQueueCommand *cmd)
 			/* Append command at the beginning */
 			g_queue_push_head (self->queue, cmd);
 			
-			dma_debugger_queue_complete (self, self->debugger_state);
+			/* We must not interrupt command having callback, as the command
+			 * will be removed, the callback when emitted will be redirected to
+			 * the handler of the next command */
+			if ((state == IANJUTA_DEBUGGER_STOPPED) || (self->debugger_state == IANJUTA_DEBUGGER_PROGRAM_RUNNING))
+			{
+				dma_debugger_queue_complete (self, self->debugger_state);
+			}
 		}
-		else if (self->prepend_command == 0)
+		else if ((self->prepend_command > 0) || dma_command_has_flag (cmd, HIGH_PRIORITY))
+		{
+			IAnjutaDebuggerState state;
+			
+			state = dma_command_is_going_to_state (cmd);
+			if (state != IANJUTA_DEBUGGER_BUSY)
+			{
+				/* Command is changing debugger state */
+				dma_queue_cancel_unexpected (self, state);
+			}
+			
+			/* Prepend command at the beginning */
+			g_queue_push_head (self->queue, cmd);
+		}
+		else
 		{
 			/* Append command at the end (in the queue) */
 			IAnjutaDebuggerState state;
@@ -745,11 +774,6 @@ dma_debugger_queue_append (DmaDebuggerQueue *self, DmaQueueCommand *cmd)
 				self->queue_state = state;
 			}
 		}
-		else
-		{
-			/* Prepend command at the beginning */
-			g_queue_push_head (self->queue, cmd);
-		}
 	
 		dma_debugger_queue_execute(self);
 		
@@ -884,7 +908,9 @@ dma_debugger_queue_dispose (GObject *obj)
 static void
 dma_debugger_queue_finalize (GObject *obj)
 {
-	/*DmaDebuggerQueue *self = DMA_DEBUGGER_QUEUE (obj);*/
+	DmaDebuggerQueue *self = DMA_DEBUGGER_QUEUE (obj);
+
+	g_queue_free (self->queue);
 
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
 }
