@@ -34,6 +34,7 @@
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "utilities.h"
 #include "info.h"
@@ -193,7 +194,7 @@ dma_thread_clear_all_stack_trace (StackTrace *self)
 }
 
 static void
-on_stack_trace_updated (const GList *stack, gpointer user_data)
+on_stack_trace_updated (const GList *stack, gpointer user_data, GError *error)
 {
 	StackTrace *self = (StackTrace *)user_data;
 	const GList *node;
@@ -202,6 +203,8 @@ on_stack_trace_updated (const GList *stack, gpointer user_data)
 	gboolean exist;
 	GdkPixbuf *pic;
 
+	if (error != NULL) return;
+	
 	model = GTK_LIST_STORE (self->current->model);
 
 	pic = gdk_pixbuf_new_from_file (ANJUTA_PIXMAP_POINTER, NULL);
@@ -222,7 +225,7 @@ on_stack_trace_updated (const GList *stack, gpointer user_data)
 			/* Check if it's the same stack frame */
 			gchar *adr;
 			gchar *args;
-			guint address;
+			gulong address;
 			guint line;
 			gboolean same;
 			
@@ -284,11 +287,19 @@ on_stack_trace_updated (const GList *stack, gpointer user_data)
 					
 		gtk_list_store_prepend (model, &iter);
 
-		adr = g_strdup_printf ("0x%x", frame->address);
+		adr = g_strdup_printf ("0x%lx", frame->address);
 		if (frame->file)
 		{
-			uri = g_strconcat ("file://", frame->file, NULL);
-			file = strrchr(uri, '/') + 1;
+			if (g_path_is_absolute (frame->file))
+			{					
+				uri = gnome_vfs_get_uri_from_local_path(frame->file);
+				file = strrchr(frame->file, G_DIR_SEPARATOR) + 1;
+			}
+			else
+			{
+				uri = NULL;
+				file = frame->file;
+			}
 		}
 		else
 		{
@@ -478,7 +489,7 @@ on_stack_view_source_activate (GtkAction *action, gpointer user_data)
 	gchar *uri;
 	guint line;
 	gchar *adr;
-	guint address;
+	gulong address;
 	
 	StackTrace* st = (StackTrace*) user_data;		
 
@@ -639,7 +650,7 @@ create_stack_trace_gui(StackTrace *st)
 	gtk_tree_view_column_set_title (column, _("Function"));
 	gtk_tree_view_append_column (st->treeview, column);
 	
-	if (dma_debugger_queue_is_supported (st->debugger, HAS_CPU))
+	if (dma_debugger_queue_is_supported (st->debugger, HAS_MEMORY))
 	{
 		/* Display address only if debugger has such concept */
 		column = gtk_tree_view_column_new ();
