@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef __TOOLS_PLUGIN__
@@ -38,7 +38,7 @@
 
 /*---------------------------------------------------------------------------*/
 
-extern GType atp_plugin_get_type (AnjutaGluePlugin *plugin);
+extern GType atp_plugin_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_ATP         (atp_plugin_get_type (NULL))
 #define ANJUTA_PLUGIN_ATP(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_PLUGIN_ATP, ATPPlugin))
 #define ANJUTA_PLUGIN_ATP_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_TYPE_PLUGIN_ATP, ATPPluginClass))
